==> ftpq-1.06.tar.gz: ftpq-1.06/src/utilities.c <==
/* ftpq: utilities.c

Copyright (C) 2000-2003 Mark Tranchant

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#include "ftpq.h"

/* memalloc(): safety wrapper for malloc() */
void *memalloc (size_t reqsize) {

	void *memptr = NULL;

	memptr = malloc (reqsize);

	if (memptr == NULL) {
		/* malloc() request denied! */
		printf ("ftpq: malloc request for %ld bytes failed!\n", (long) reqsize);
		exit (AB_MALLOC);
	}

	return memptr;
}


/* fileopen(): safety wrapper for fopen() */
FILE *fileopen (char *filename, int mode, int option) {

	FILE *fileptr = NULL;

	if (mode == FO_READ)
		fileptr = fopen(filename, "r");
	if (mode == FO_WRITE)
		fileptr = fopen(filename, "w");

	if (fileptr == NULL) {
		switch (errno) {
		  case ENOENT:
			/* file doesn't exist - only a problem if we need it */
			if (option == FO_NEED) {
				printf("ftpq: can't find file %s!\n", filename);
				exit(AB_NOFILE);
			}
			break;
		  case EACCES:
			/* permission denied! */
			if (mode == FO_READ) {
				if (option == FO_NEED) {
					printf("ftpq: permission to read %s denied!\n", filename);
					exit(AB_NOPERM);
				}
			}
			else {
				printf("ftpq: permission to write %s denied!\n", filename);
				exit(AB_NOPERM);
			}
			break;
		  default:
			/* other error */
			printf("ftpq: File error in %s\n!", filename);
			exit(AB_FILEERR);
		}
	}
	return fileptr;
}

int fileputc (int mchar, FILE *fileptr) {

	if (fputc (mchar, fileptr) == EOF) {
		if (fileptr != NULL) {
			printf("ftpq: file writing error!\n\n");
			exit (AB_FILEERR);
		}
		return 0;
	}
	return 1;
}

==> ftpq-1.11.tar.gz: ftpq-1.11/src/utilities.c <==
/* ftpq: utilities.c

Copyright (C) 2000, 2001 Mark Tranchant

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#include "ftpq.h"

/* memalloc(): safety wrapper for malloc() */
void *memalloc (size_t reqsize) {

	void *memptr = NULL;

	memptr = (void *) malloc (reqsize);

	if (memptr == NULL) {
		/* malloc() request denied! */
		printf ("ftpq: malloc request for %ld bytes failed!\n", (long) reqsize);
		exit (AB_MALLOC);
	}

	return memptr;
}


/* fileopen(): safety wrapper for fopen() */
FILE *fileopen (char *filename, int option) {

	FILE *fileptr = NULL;

	if (option & FO_READ)
		fileptr = fopen(filename, "r");
	else if (option & FO_WRITE)
		fileptr = fopen(filename, "w");

	if (fileptr == NULL) {
		switch (errno) {
		  case ENOENT:
			/* file doesn't exist - only a problem if we need it */
			if ((option & FO_NEED) && (option & FO_READ)) {
				printf("ftpq: can't find file %s!\n", filename);
				exit(AB_NOFILE);
			}
			break;
		  case EACCES:
			/* permission denied! */
			if (option & FO_READ) {
				if (option & FO_NEED) {
					printf("ftpq: permission to read %s denied!\n", filename);
					exit(AB_NOPERM);
				}
			}
			else {
				printf("ftpq: permission to write %s denied!\n", filename);
				exit(AB_NOPERM);
			}
			break;
		  default:
			/* other error */
			printf("ftpq: File error in %s\n!", filename);
			exit(AB_FILEERR);
		}
	}
	return fileptr;
}

int fileputc (int mchar, FILE *fileptr) {

	if (fputc (mchar, fileptr) == EOF) {
		if (fileptr != NULL) {
			printf("ftpq: file writing error!\n\n");
			exit (AB_FILEERR);
		}
		return 0;
	}
	return 1;
}
